
#ifndef _MPL_PANEL_COMMON
#define _MPL_PANEL_COMMON

#define MPL_PANEL_DBUS_NAME_PREFIX "org.moblin.UX.Shell.Panels."
#define MPL_PANEL_DBUS_PATH_PREFIX "/org/moblin/UX/Shell/Panels/"
#define MPL_PANEL_DBUS_INTERFACE   "org.moblin.UX.Shell.Panel"

#define MPL_TOOLBAR_DBUS_PATH      "/org/moblin/UX/Shell/Toolbar"
#define MPL_TOOLBAR_DBUS_NAME      "org.moblin.UX.Shell.Toolbar"
#define MPL_TOOLBAR_DBUS_INTERFACE "org.moblin.UX.Shell.Toolbar"

#define MPL_PANEL_MYZONE       "myzone"
#define MPL_PANEL_STATUS       "status"
#define MPL_PANEL_ZONES        "zones"
#define MPL_PANEL_INTERNET     "internet"
#define MPL_PANEL_MEDIA        "media"
#define MPL_PANEL_APPLICATIONS "applications"
#define MPL_PANEL_PEOPLE       "people"
#define MPL_PANEL_PASTEBOARD   "pasteboard"
#define MPL_PANEL_NETWORK      "network"
#define MPL_PANEL_BLUETOOTH    "bluetooth"
#define MPL_PANEL_VOLUME       "volume"
#define MPL_PANEL_POWER        "power"
#define MPL_PANEL_TEST         "test"

typedef enum
{
  MNB_BUTTON_NORMAL      = 0,
  MNB_BUTTON_HIDDEN      = 0x1,
  MNB_BUTTON_INSENSITIVE = 0x2
} MnbButtonState;

#endif
